@@ -23,9 +23,8 @@ CLI_VERSION = 'cli {}'.format(__version__)
 
 @click.group()
 @click.option(u"-v", u"--verbose", count=True, help=u"Turn on debug logging")
-@click.option(u"-t", u"--docker-tag", default=u"latest", help=u"Specify tag for Docker image")
 @click.pass_context
-def cli(ctx, verbose, docker_tag):
+def cli(ctx, verbose):
     """
     CLI tool built to add simple functionality to sagify development.
     """
@@ -33,7 +32,7 @@ def cli(ctx, verbose, docker_tag):
     logger=configure_logger('mldock', verbose=verbose)
     logger.info(MLDOCK_LOGO)
     logger.info('Version: ' + CLI_VERSION)
-    ctx.obj = {'verbose': verbose, 'docker_tag': docker_tag, 'helper_library_path':_FILE_DIR_PATH, 'logo':MLDOCK_LOGO}
+    ctx.obj = {'verbose': verbose, 'helper_library_path':_FILE_DIR_PATH, 'logo':MLDOCK_LOGO}
 
 def add_commands(cli):
     cli.add_command(container)
