@@ -9,7 +9,7 @@ from future.moves import subprocess
 from mldock.config.config_manager import \
     ResourceConfigManager, MLDockConfigManager, PackageConfigManager, \
         HyperparameterConfigManager, InputDataConfigManager, WorkingDirectoryManager, \
-            EnvironmentConfigManager
+            EnvironmentConfigManager, StageConfigManager
 from mldock.api.local import \
     _copy_boilerplate_to_dst, _rename_file
 
@@ -59,8 +59,9 @@ def create_template(obj, name, dir, out):
 @click.option('--service', default=None, help='(Optional) Docker Compose. This seeds a service config.')
 @click.option('--no-prompt', is_flag=True, help='Do not prompt user, instead use the mldock config to initialize the container.')
 @click.option('--container-only', is_flag=True, help='Only inject new container assets.')
+@click.option('--template', default=None, help='Directory containing mldock supported container to use to initialize the container.')
 @click.pass_obj
-def init(obj, dir, testing_framework, service, no_prompt, container_only):
+def init(obj, dir, testing_framework, service, no_prompt, container_only, template):
     """
     Command to initialize container configs required by sagemaker-training.
     """
@@ -98,7 +99,11 @@ def init(obj, dir, testing_framework, service, no_prompt, container_only):
         working_directory_manager = WorkingDirectoryManager(base_dir=dir)
         # sagemaker
         config_path = working_directory_manager.input_config_dir
-        # get hyperparameters
+
+        # create stages config
+        stage_config_manager = StageConfigManager(
+            config=mldock_config.get('stages', {})
+        )
         # set input data channels
         input_data_channels = InputDataConfigManager(
             config=mldock_config.get('data', [])
@@ -115,6 +120,8 @@ def init(obj, dir, testing_framework, service, no_prompt, container_only):
         )
 
         if not no_prompt:
+            stage_config_manager.ask_for_stages()
+            mldock_manager.update_stages(stages=stage_config_manager.get_config())
             input_data_channels.ask_for_input_data_channels()
             mldock_manager.update_data_channels(data=input_data_channels.get_config())
             hyperparameters.ask_for_hyperparameters()
@@ -136,7 +143,8 @@ def init(obj, dir, testing_framework, service, no_prompt, container_only):
                 no_prompt=no_prompt,
                 testing_framework=testing_framework,
                 service=service,
-                container_only=container_only
+                container_only=container_only,
+                template_dir=template
             )
         elif platform == "sagemakerv2":
             # pass down any information like hyperparameters, etc
@@ -147,7 +155,8 @@ def init(obj, dir, testing_framework, service, no_prompt, container_only):
                 no_prompt=no_prompt,
                 testing_framework=testing_framework,
                 service=service,
-                container_only=container_only
+                container_only=container_only,
+                template_dir=template
             )
         elif platform == "generic":
             # pass down any information like hyperparameters, etc
@@ -164,11 +173,80 @@ def init(obj, dir, testing_framework, service, no_prompt, container_only):
 
         logger.info("\nlocal container volume is ready! ヽ(´▽`)/")
     except subprocess.CalledProcessError as e:
-        logger.debug(e.output)
-        raise
+        logger.error(e.output)
+        sys.exit(-1)
+    except Exception as e:
+        logger.error("{}".format(e))
+        sys.exit(-1)
+
+@click.command()
+@click.option('--dir', help='Set the working directory for your sagify container.', required=True)
+@click.pass_obj
+def update(obj, dir):
+    """
+    Command to initialize container configs required by sagemaker-training.
+    """
+    helper_library_path=obj['helper_library_path']
+    try:
+        logger.info("Initializing MLDock config")
+        mldock_manager = MLDockConfigManager(
+            filepath=os.path.join(dir, ".mldock.json")
+        )
+
+        # get sagify_module_path name
+        mldock_config = mldock_manager.get_config()
+        src_directory = os.path.join(
+            dir,
+            mldock_config.get("mldock_module_dir", "src")
+        )
+        mldock_module_path = os.path.join(
+            src_directory,
+            'container'
+        )
+
+        working_directory_manager = WorkingDirectoryManager(base_dir=dir)
+        # sagemaker
+        config_path = working_directory_manager.input_config_dir
+
+        # create stages config
+        stage_config_manager = StageConfigManager(
+            config=mldock_config.get('stages', {})
+        )
+        # set input data channels
+        input_data_channels = InputDataConfigManager(
+            config=mldock_config.get('data', [])
+        )
+
+        # set hyperparameters
+        hyperparameters = HyperparameterConfigManager(
+            config=mldock_config.get('hyperparameters', {})
+        )
+
+        # set environment variables
+        environment = EnvironmentConfigManager(
+            config=mldock_config.get('environment', {})
+        )
+
+        stage_config_manager.ask_for_stages()
+        mldock_manager.update_stages(stages=stage_config_manager.get_config())
+        input_data_channels.ask_for_input_data_channels()
+        mldock_manager.update_data_channels(data=input_data_channels.get_config())
+        hyperparameters.ask_for_hyperparameters()
+        mldock_manager.update_hyperparameters(hyperparameters=hyperparameters.get_config())
+        environment.ask_for_env_vars()
+        mldock_manager.update_env_vars(environment=environment.get_config())
+
+        mldock_manager.write_file()
+        mldock_manager.pretty_print()
+
+        logger.info("\nlocal container was updated! ヽ(´▽`)/")
+    except subprocess.CalledProcessError as e:
+        logger.error(e.output)
+        sys.exit(-1)
     except Exception as e:
         logger.error("{}".format(e))
         sys.exit(-1)
 
 container.add_command(init)
+container.add_command(update)
 container.add_command(create_template)
